==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfUnitConvertor.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfUnitConvertor(SpireObject):
    """
    Class allowing to convert different unit metrics. Converting is based on Graphics object DPI settings that is why for different graphics settings must be created new instance. For example, printers often have 300 and greater dpi resolution, while the default display screen dpi is 96.
    """

    @dispatch
    def __init__(self, dpi: float):
        """
        Initializes a new instance of the PdfUnitConvertor class with the specified DPI.
        """
        GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertorD.argtypes = [c_float]
        GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertorD.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertorD(dpi)
        super(PdfUnitConvertor, self).__init__(intPtr)

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfUnitConvertor class with the default DPI.
        """
        GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertor.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertor()
        super(PdfUnitConvertor, self).__init__(intPtr)

    def ConvertUnits(self, value: float, fromF: 'PdfGraphicsUnit', to: 'PdfGraphicsUnit') -> float:
        """
        Converts the specified value from one unit to another.
        """
        enumfrom: c_int = fromF.value
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertUnits.argtypes = [c_void_p, c_float, c_int, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertUnits.restype = c_float
        ret = GetDllLibPdf().PdfUnitConvertor_ConvertUnits(self.Ptr, value, enumfrom, enumto)
        return ret

    @dispatch
    def ConvertToPixels(self, value: float, fromF: PdfGraphicsUnit) -> float:
        """
        Converts the specified value from the specified unit to pixels.
        """
        enumfrom: c_int = fromF.value

        GetDllLibPdf().PdfUnitConvertor_ConvertToPixels.argtypes = [c_void_p, c_float, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertToPixels.restype = c_float
        ret = GetDllLibPdf().PdfUnitConvertor_ConvertToPixels(self.Ptr, value, enumfrom)
        return ret

    @dispatch
    def ConvertToPixels(self, rect: RectangleF, fromF: PdfGraphicsUnit) -> RectangleF:
        """
        Converts the specified rectangle from the specified unit to pixels.
        """
        intPtrrect: c_void_p = rect.Ptr
        enumfrom: c_int = fromF.value

        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsRF.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsRF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsRF(self.Ptr, intPtrrect, enumfrom)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @dispatch
    def ConvertToPixels(self, point: PointF, fromF: PdfGraphicsUnit) -> PointF:
        """
        Converts the specified point from the specified unit to pixels.
        """
        intPtrpoint: c_void_p = point.Ptr
        enumfrom: c_int = fromF.value

        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsPF.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsPF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsPF(self.Ptr, intPtrpoint, enumfrom)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @dispatch
    def ConvertToPixels(self, size: SizeF, fromF: PdfGraphicsUnit) -> SizeF:
        """
        Converts the specified size from the specified unit to pixels.
        """
        intPtrsize: c_void_p = size.Ptr
        enumfrom: c_int = fromF.value

        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsSF.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsSF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsSF(self.Ptr, intPtrsize, enumfrom)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @dispatch
    def ConvertFromPixels(self, value: float, to: PdfGraphicsUnit) -> float:
        """
        Converts the specified value from pixels to the specified unit.
        """
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixels.argtypes = [c_void_p, c_float, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixels.restype = c_float
        ret = GetDllLibPdf().PdfUnitConvertor_ConvertFromPixels(self.Ptr, value, enumto)
        return ret

    @dispatch
    def ConvertFromPixels(self, rect: RectangleF, to: PdfGraphicsUnit) -> RectangleF:
        """
        Converts the specified rectangle from pixels to the specified unit.
        """
        intPtrrect: c_void_p = rect.Ptr
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsRT.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsRT.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsRT(self.Ptr, intPtrrect, enumto)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @dispatch
    def ConvertFromPixels(self, point: PointF, to: PdfGraphicsUnit) -> PointF:
        """
        Converts the specified point from pixels to the specified unit.
        """
        intPtrpoint: c_void_p = point.Ptr
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsPT.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsPT.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsPT(self.Ptr, intPtrpoint, enumto)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @dispatch
    def ConvertFromPixels(self, size: SizeF, to: PdfGraphicsUnit) -> SizeF:
        """
        Converts the specified size from pixels to the specified unit.
        """
        intPtrsize: c_void_p = size.Ptr
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsST.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsST.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsST(self.Ptr, intPtrsize, enumto)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfUnitConvertor.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfUnitConvertor(SpireObject):
    """
    Class allowing to convert different unit metrics. Converting is based on Graphics object DPI settings that is why for different graphics settings must be created new instance. For example, printers often have 300 and greater dpi resolution, while the default display screen dpi is 96.
    """

    @dispatch
    def __init__(self, dpi: float):
        """
        Initializes a new instance of the PdfUnitConvertor class with the specified DPI.
        """
        GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertorD.argtypes = [c_float]
        GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertorD.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertorD,dpi)
        super(PdfUnitConvertor, self).__init__(intPtr)

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfUnitConvertor class with the default DPI.
        """
        GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertor.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnitConvertor_CreatePdfUnitConvertor)
        super(PdfUnitConvertor, self).__init__(intPtr)

    def ConvertUnits(self, value: float, fromF: 'PdfGraphicsUnit', to: 'PdfGraphicsUnit') -> float:
        """
        Converts the specified value from one unit to another.
        """
        enumfrom: c_int = fromF.value
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertUnits.argtypes = [c_void_p, c_float, c_int, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertUnits.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertUnits,self.Ptr, value, enumfrom, enumto)
        return ret

    @dispatch
    def ConvertToPixels(self, value: float, fromF: PdfGraphicsUnit) -> float:
        """
        Converts the specified value from the specified unit to pixels.
        """
        enumfrom: c_int = fromF.value

        GetDllLibPdf().PdfUnitConvertor_ConvertToPixels.argtypes = [c_void_p, c_float, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertToPixels.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertToPixels,self.Ptr, value, enumfrom)
        return ret

    @dispatch
    def ConvertToPixels(self, rect: RectangleF, fromF: PdfGraphicsUnit) -> RectangleF:
        """
        Converts the specified rectangle from the specified unit to pixels.
        """
        intPtrrect: c_void_p = rect.Ptr
        enumfrom: c_int = fromF.value

        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsRF.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsRF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsRF,self.Ptr, intPtrrect, enumfrom)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @dispatch
    def ConvertToPixels(self, point: PointF, fromF: PdfGraphicsUnit) -> PointF:
        """
        Converts the specified point from the specified unit to pixels.
        """
        intPtrpoint: c_void_p = point.Ptr
        enumfrom: c_int = fromF.value

        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsPF.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsPF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsPF,self.Ptr, intPtrpoint, enumfrom)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @dispatch
    def ConvertToPixels(self, size: SizeF, fromF: PdfGraphicsUnit) -> SizeF:
        """
        Converts the specified size from the specified unit to pixels.
        """
        intPtrsize: c_void_p = size.Ptr
        enumfrom: c_int = fromF.value

        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsSF.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsSF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertToPixelsSF,self.Ptr, intPtrsize, enumfrom)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @dispatch
    def ConvertFromPixels(self, value: float, to: PdfGraphicsUnit) -> float:
        """
        Converts the specified value from pixels to the specified unit.
        """
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixels.argtypes = [c_void_p, c_float, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixels.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertFromPixels,self.Ptr, value, enumto)
        return ret

    @dispatch
    def ConvertFromPixels(self, rect: RectangleF, to: PdfGraphicsUnit) -> RectangleF:
        """
        Converts the specified rectangle from pixels to the specified unit.
        """
        intPtrrect: c_void_p = rect.Ptr
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsRT.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsRT.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsRT,self.Ptr, intPtrrect, enumto)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @dispatch
    def ConvertFromPixels(self, point: PointF, to: PdfGraphicsUnit) -> PointF:
        """
        Converts the specified point from pixels to the specified unit.
        """
        intPtrpoint: c_void_p = point.Ptr
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsPT.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsPT.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsPT,self.Ptr, intPtrpoint, enumto)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @dispatch
    def ConvertFromPixels(self, size: SizeF, to: PdfGraphicsUnit) -> SizeF:
        """
        Converts the specified size from pixels to the specified unit.
        """
        intPtrsize: c_void_p = size.Ptr
        enumto: c_int = to.value

        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsST.argtypes = [c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsST.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfUnitConvertor_ConvertFromPixelsST,self.Ptr, intPtrsize, enumto)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret
